==> prestashop_1.4.0.10.zip: prestashop/modules/twenga/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{twenga}prestashop>twenga_400b0c914f01bcecf50b936e652695b2'] = 'El API de Twenga';
$_MODULE['<{twenga}prestashop>twenga_aa2bebad4fe3e659723e56cc7fcc6b1c'] = 'Exporte sus productos en Twenga.com y utilice el Tracker de Twenga para los pedidos de sus consumidores.';
$_MODULE['<{twenga}prestashop>twenga_69e591b18e717d483dbaa8e3ce89ce59'] = 'Los parámetros no son autorizados (ver detalles):';
$_MODULE['<{twenga}prestashop>twenga_75a462904fadc0cc16d084efaef4a9d0'] = 'Se ha producido un error con un método de API Twenga (ver detalles):';
$_MODULE['<{twenga}prestashop>twenga_cecc441ee7cb4cbbf1953d44018706de'] = 'Su “Haskell” no es válido: Compruebe el email enviado por Twenga.';
$_MODULE['<{twenga}prestashop>twenga_0483e8a340c21e92e606aa0cd2bafbe7'] = 'Su nombre de usuario no es válido. Compruebe el email enviado por Twenga.';
$_MODULE['<{twenga}prestashop>twenga_54d92b2c87281ba0247f14a8eaea3278'] = 'Su contraseña no es válida. Compruebe el email enviado por Twenga.';
$_MODULE['<{twenga}prestashop>twenga_b0d43a97cdf2e31e3d6b26640c2e71ee'] = 'Su autentificación ha fracasado.';
$_MODULE['<{twenga}prestashop>twenga_638a1f975b1d8361fcd459c532db6634'] = 'Compruebe el email enviado por Twenga en el momento de la inscripción. Si los errores continúan contacte con el servicio de Twenga.';
$_MODULE['<{twenga}prestashop>twenga_ddedf0f7b923553ef46616375e521381'] = 'Se ha producido un error al pasar los parámetros a el API Twenga.';
$_MODULE['<{twenga}prestashop>twenga_378f76d06c0d43d9fe5b5ab561e06d09'] = 'Para utilizar el webservicio de Twenga, debe activar la extensión “curl” de PHP';
$_MODULE['<{twenga}prestashop>twenga_9dca934235686e38b44b0bdc2b200fd1'] = 'Se han producido errores al llamar al método \"get subscription\" con el API de Twenga';
$_MODULE['<{twenga}prestashop>twenga_afd85c83036222c2ae9c74a72005f01a'] = 'Referencie sus productos en Twenga: ¡PrestaShop le regala 500 clics!';
$_MODULE['<{twenga}prestashop>twenga_8ec93b2766f968644dddb84ac631d8eb'] = 'Como probar Twenga y beneficiarse de los 500 primeros clics gratis';
$_MODULE['<{twenga}prestashop>twenga_06514ba3847ede064473195f4be6e2a4'] = 'Etapa 1: Pulse en este link especial para inscribirse a \"Twenga Ready to Sell\"';
$_MODULE['<{twenga}prestashop>twenga_4f893ee24950069dd823e083338a456d'] = 'inscribirse';
$_MODULE['<{twenga}prestashop>twenga_d4841389a7d896c92ecb8d81c0f42abf'] = '(se han producido errores: contacte con Twenga)';
$_MODULE['<{twenga}prestashop>twenga_62876cf525e6d041d430830a82da963a'] = 'Etapa 2: Complete el formulario de inscripción Twenga';
$_MODULE['<{twenga}prestashop>twenga_4171a285413429b40924497afe96c9f5'] = 'Etapa 3: Una vez que haya recibido su clave Twenga, vuelva aquí e introduzca la clave en el campo \"hash key\" así como su login/pass Twenga Ready to Sell.';
$_MODULE['<{twenga}prestashop>twenga_bc88fe7063d7e7da0bf08003f21a1ad2'] = 'Aumente su tráfico - 500 clics gratis';
$_MODULE['<{twenga}prestashop>twenga_f9372612b4e86b53c45d31d7ca3402bb'] = 'Tarifas de Twenga';
$_MODULE['<{twenga}prestashop>twenga_744dfa52994785191424076b2d949bf5'] = 'Su catálogo se referenciará en unos diez días. Una vez que haya utilizado los 500 clics, cada clic se facturará por categoría entre 0.05€ y 0.15€. Tendrá acceso a una interfaz de gestión completa. Es posible deinscribirse en todo momento previo aviso de un mes. ';
$_MODULE['<{twenga}prestashop>twenga_f57624e0e72283c798dbd6cf90eed6ce'] = 'Autentificación';
$_MODULE['<{twenga}prestashop>twenga_e60a169b3000fea758d98ccec0363eb6'] = 'Después de haber rellenado las etapas 1 y 2, escriba aquí la clave Twenga y su login Twenga Ready to Sell';
$_MODULE['<{twenga}prestashop>twenga_a66daa775d445ee7da1bb20667b7c8e6'] = 'Flujo RSS';
$_MODULE['<{twenga}prestashop>twenga_21baf392bfae2dadba6813e9fb843141'] = 'Hashkey';
$_MODULE['<{twenga}prestashop>twenga_99dea78007133396a7b8ed70578ac6ae'] = 'Login';
$_MODULE['<{twenga}prestashop>twenga_dc647eb65e6711e155375218212b3964'] = 'Contraseña';
$_MODULE['<{twenga}prestashop>twenga_4c6f9d401a4794114c14be43eb6306c7'] = 'Su catálogo se referenciará en Twenga en unos diez días';
$_MODULE['<{twenga}prestashop>twenga_43781db5c40ecc39fd718685594f0956'] = 'Guardar';
$_MODULE['<{twenga}prestashop>twenga_a0dbbe61662edf3ce539b487aabf8496'] = 'Datos que aparecen rellenados en el formulario de inscripción Twenga';
$_MODULE['<{twenga}prestashop>twenga_2b18bce4cc00bb36510ba7a27f40c208'] = 'Los siguientes datos ya aparecen rellenados en el momento de su inscripción en Twenga Ready to Sell. Compruebe que estos datos son correctos. ';
$_MODULE['<{twenga}prestashop>twenga_87fa3060dcb794dee724d4cb59b13cd6'] = 'La URL del sitio';
$_MODULE['<{twenga}prestashop>twenga_1ce44171ccfff23c4fc2c836ad6543f4'] = 'Flujo RSS, lista de productos en xml.';
$_MODULE['<{twenga}prestashop>twenga_670e0c29cdde1886890aebc751cd6e89'] = 'Valor rellenado automáticamente, no cambiar.';
$_MODULE['<{twenga}prestashop>twenga_59716c97497eb9694541f7c3d37b1a4d'] = 'País';
$_MODULE['<{twenga}prestashop>twenga_95f01a5bae7b4b64a76372538e4fd315'] = 'El país de la empresa E-Comercio. Utilice el código ISO_3166-1 Alpha-2 para el formato del país';
$_MODULE['<{twenga}prestashop>twenga_734b599bad38d4210614bc176c53fefe'] = 'Nombre del sitio';
$_MODULE['<{twenga}prestashop>twenga_dff4bf10409100d989495c6d5486035e'] = 'Apellido';
$_MODULE['<{twenga}prestashop>twenga_04176f095283bc729f1e3926967e7034'] = 'Nombre';
$_MODULE['<{twenga}prestashop>twenga_ce8ae9da5b7cd6c3df2929543a9af92d'] = 'Email';
$_MODULE['<{twenga}prestashop>twenga_bcc254b55c4a1babdf1dcb82c207506b'] = 'Teléfono';
$_MODULE['<{twenga}prestashop>twenga_28bea34e08fa23a7d394c93bad717733'] = 'Nombre del organismo';
$_MODULE['<{twenga}prestashop>twenga_4ff5049a0938728934387c4d9cf38f94'] = 'Información jurídica';
$_MODULE['<{twenga}prestashop>twenga_dfd7564600980a3470f2ec24766653fe'] = 'Información jurídica de la empresa.';
$_MODULE['<{twenga}prestashop>twenga_dd7bf230fde8d4836917806aff6a6b27'] = 'Dirección';
$_MODULE['<{twenga}prestashop>twenga_572ed696f21038e6cc6c86bb272a3222'] = 'Código postal';
$_MODULE['<{twenga}prestashop>twenga_57d056ed0984166336b7879c2af3657f'] = 'Ciudad';
$_MODULE['<{twenga}prestashop>twenga_c9cc8cce247e49bae79f15173ce97354'] = 'Guardar';
$_MODULE['<{twenga}prestashop>twenga_fcb0c2a30548efc7048ea4bdfa4eba05'] = 'Anular el tracking';
$_MODULE['<{twenga}prestashop>twenga_08473b95892d1cb8265ff2716cb81d54'] = 'Para anular el tracking, pulse en el siguiente link:';
$_MODULE['<{twenga}prestashop>twenga_bcfaccebf745acfd5e75351095a5394a'] = 'Anular';
$_MODULE['<{twenga}prestashop>twenga_2938a03ab100963b7349d83257fa9333'] = 'Activar el tracking';
$_MODULE['<{twenga}prestashop>twenga_cd07439a0c70b97a595de73218094a36'] = 'Para activar el tracking, pulse en el siguiente link:';
$_MODULE['<{twenga}prestashop>twenga_a13367a8e2a3f3bf4f3409079e3fdf87'] = 'Activar';
$_MODULE['<{twenga}prestashop>TwengaObj_2823b98d043387f608f16d5830d63f5f'] = 'Para activar el módulo Twenga, la constante \"PARTNER_AUTH_KEY\" debe estar definida. La instalación por defecto de PrestaShop contiene este valor.';
$_MODULE['<{twenga}prestashop>TwengaObj_9f7cd403f4ab77ce8c00426d4a01345e'] = 'El objeto para validar los campos debe ser una instancia de la clase TwengaFields';
$_MODULE['<{twenga}prestashop>TwengaObj_b78d4ca3fa82bab9e21c8110511ed947'] = 'La devolución XML de la respuesta HTTP no puede ser analizada:';
$_MODULE['<{twenga}prestashop>TwengaObj_7edc522b57a063ef075b68fdb791af40'] = 'la respuesta HTTP está vacía';
$_MODULE['<{twenga}prestashop>TwengaObj_d00d3f61833c8686be3f0ca7df670e20'] = 'La llamada a los servicios Web Twenga no se ha obtenido con éxito y a devuelto un estado HTTP de %d. Lo que significa:';
$_MODULE['<{twenga}prestashop>TwengaObj_5177c3a8e526ccb227441827d43d9583'] = 'La función que ha llamado no existe';
$_MODULE['<{twenga}prestashop>TwengaObj_3718cdfdc7439f35aed9f053b5991baf'] = 'Un campo requerido está vacío.';
$_MODULE['<{twenga}prestashop>TwengaObj_f97fd38d65fe891d07fc1a157b0752a2'] = 'El tipo de parámetro que ha enviado es diferente del que se esperaba.';
$_MODULE['<{twenga}prestashop>TwengaObj_737b702af5cbf3c4b0e7404592bae85e'] = 'El hash key no es válido';
$_MODULE['<{twenga}prestashop>TwengaObj_c54550e963195bd4e80b862f40b8d574'] = 'Se requiere el hash key';
$_MODULE['<{twenga}prestashop>TwengaObj_c4e170c475b0285f284ccb066bcd81f4'] = 'No se han encontrado pedidos. Compruebe los parámetros que transmite';
$_MODULE['<{twenga}prestashop>TwengaObj_54441256ce04ab07a29463646d0a9931'] = 'Se requiere una autentificación.';
$_MODULE['<{twenga}prestashop>TwengaObj_802b207b05fe5cea22e11b9db804b33d'] = 'La autentificación ha fracasado.';
$_MODULE['<{twenga}prestashop>TwengaObj_629a8cfa226f98886062bfdc9666e266'] = 'La URL no es válida.';
$_MODULE['<{twenga}prestashop>TwengaObj_9fb66ea632c1aff220b180918df3c77c'] = 'El servidor ha encontrado un \"internal server error\".';
$_MODULE['<{twenga}prestashop>TwengaObj_6e182f2ba494a6720ce552ed2a255403'] = 'El servidor no está accesible por el momento';
$_MODULE['<{twenga}prestashop>TwengaObj_4252fb7eb531ed1ec250e5c16f8ced37'] = 'La llamada a los servicios Web Twenga a devuelto un estado HTTP inesperado:';
$_MODULE['<{twenga}prestashop>TwengaObj_5619f08f21127bd8f72ec9bbb25031ac'] = 'Error  n°';

==> prestashop_1.4.0.14.zip: prestashop/modules/twenga/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{twenga}prestashop>twenga_400b0c914f01bcecf50b936e652695b2'] = 'El API de Twenga';
$_MODULE['<{twenga}prestashop>twenga_aa2bebad4fe3e659723e56cc7fcc6b1c'] = 'Exporte sus productos en Twenga.com y utilice el Tracker de Twenga para los pedidos de sus consumidores.';
$_MODULE['<{twenga}prestashop>twenga_69e591b18e717d483dbaa8e3ce89ce59'] = 'Los parámetros no son autorizados (ver detalles):';
$_MODULE['<{twenga}prestashop>twenga_75a462904fadc0cc16d084efaef4a9d0'] = 'Se ha producido un error con un método de API Twenga (ver detalles):';
$_MODULE['<{twenga}prestashop>twenga_cecc441ee7cb4cbbf1953d44018706de'] = 'Su “Haskell” no es válido: Compruebe el email enviado por Twenga.';
$_MODULE['<{twenga}prestashop>twenga_0483e8a340c21e92e606aa0cd2bafbe7'] = 'Su nombre de usuario no es válido. Compruebe el email enviado por Twenga.';
$_MODULE['<{twenga}prestashop>twenga_54d92b2c87281ba0247f14a8eaea3278'] = 'Su contraseña no es válida. Compruebe el email enviado por Twenga.';
$_MODULE['<{twenga}prestashop>twenga_b0d43a97cdf2e31e3d6b26640c2e71ee'] = 'Su autentificación ha fracasado.';
$_MODULE['<{twenga}prestashop>twenga_638a1f975b1d8361fcd459c532db6634'] = 'Compruebe el email enviado por Twenga en el momento de la inscripción. Si los errores continúan contacte con el servicio de Twenga.';
$_MODULE['<{twenga}prestashop>twenga_ddedf0f7b923553ef46616375e521381'] = 'Se ha producido un error al pasar los parámetros a el API Twenga.';
$_MODULE['<{twenga}prestashop>twenga_378f76d06c0d43d9fe5b5ab561e06d09'] = 'Para utilizar el webservicio de Twenga, debe activar la extensión “curl” de PHP';
$_MODULE['<{twenga}prestashop>twenga_9dca934235686e38b44b0bdc2b200fd1'] = 'Se han producido errores al llamar al método \"get subscription\" con el API de Twenga';
$_MODULE['<{twenga}prestashop>twenga_afd85c83036222c2ae9c74a72005f01a'] = 'Referencie sus productos en Twenga: ¡PrestaShop le regala 500 clics!';
$_MODULE['<{twenga}prestashop>twenga_8ec93b2766f968644dddb84ac631d8eb'] = 'Como probar Twenga y beneficiarse de los 500 primeros clics gratis';
$_MODULE['<{twenga}prestashop>twenga_06514ba3847ede064473195f4be6e2a4'] = 'Etapa 1: Pulse en este link especial para inscribirse a \"Twenga Ready to Sell\"';
$_MODULE['<{twenga}prestashop>twenga_4f893ee24950069dd823e083338a456d'] = 'inscribirse';
$_MODULE['<{twenga}prestashop>twenga_d4841389a7d896c92ecb8d81c0f42abf'] = '(se han producido errores: contacte con Twenga)';
$_MODULE['<{twenga}prestashop>twenga_62876cf525e6d041d430830a82da963a'] = 'Etapa 2: Complete el formulario de inscripción Twenga';
$_MODULE['<{twenga}prestashop>twenga_4171a285413429b40924497afe96c9f5'] = 'Etapa 3: Una vez que haya recibido su clave Twenga, vuelva aquí e introduzca la clave en el campo \"hash key\" así como su login/pass Twenga Ready to Sell.';
$_MODULE['<{twenga}prestashop>twenga_bc88fe7063d7e7da0bf08003f21a1ad2'] = 'Aumente su tráfico - 500 clics gratis';
$_MODULE['<{twenga}prestashop>twenga_f9372612b4e86b53c45d31d7ca3402bb'] = 'Tarifas de Twenga';
$_MODULE['<{twenga}prestashop>twenga_744dfa52994785191424076b2d949bf5'] = 'Su catálogo se referenciará en unos diez días. Una vez que haya utilizado los 500 clics, cada clic se facturará por categoría entre 0.05€ y 0.15€. Tendrá acceso a una interfaz de gestión completa. Es posible deinscribirse en todo momento previo aviso de un mes. ';
$_MODULE['<{twenga}prestashop>twenga_f57624e0e72283c798dbd6cf90eed6ce'] = 'Autentificación';
$_MODULE['<{twenga}prestashop>twenga_e60a169b3000fea758d98ccec0363eb6'] = 'Después de haber rellenado las etapas 1 y 2, escriba aquí la clave Twenga y su login Twenga Ready to Sell';
$_MODULE['<{twenga}prestashop>twenga_a66daa775d445ee7da1bb20667b7c8e6'] = 'Flujo RSS';
$_MODULE['<{twenga}prestashop>twenga_21baf392bfae2dadba6813e9fb843141'] = 'Hashkey';
$_MODULE['<{twenga}prestashop>twenga_99dea78007133396a7b8ed70578ac6ae'] = 'Login';
$_MODULE['<{twenga}prestashop>twenga_dc647eb65e6711e155375218212b3964'] = 'Contraseña';
$_MODULE['<{twenga}prestashop>twenga_4c6f9d401a4794114c14be43eb6306c7'] = 'Su catálogo se referenciará en Twenga en unos diez días';
$_MODULE['<{twenga}prestashop>twenga_43781db5c40ecc39fd718685594f0956'] = 'Guardar';
$_MODULE['<{twenga}prestashop>twenga_a0dbbe61662edf3ce539b487aabf8496'] = 'Datos que aparecen rellenados en el formulario de inscripción Twenga';
$_MODULE['<{twenga}prestashop>twenga_2b18bce4cc00bb36510ba7a27f40c208'] = 'Los siguientes datos ya aparecen rellenados en el momento de su inscripción en Twenga Ready to Sell. Compruebe que estos datos son correctos. ';
$_MODULE['<{twenga}prestashop>twenga_87fa3060dcb794dee724d4cb59b13cd6'] = 'La URL del sitio';
$_MODULE['<{twenga}prestashop>twenga_1ce44171ccfff23c4fc2c836ad6543f4'] = 'Flujo RSS, lista de productos en xml.';
$_MODULE['<{twenga}prestashop>twenga_670e0c29cdde1886890aebc751cd6e89'] = 'Valor rellenado automáticamente, no cambiar.';
$_MODULE['<{twenga}prestashop>twenga_59716c97497eb9694541f7c3d37b1a4d'] = 'País';
$_MODULE['<{twenga}prestashop>twenga_95f01a5bae7b4b64a76372538e4fd315'] = 'El país de la empresa E-Comercio. Utilice el código ISO_3166-1 Alpha-2 para el formato del país';
$_MODULE['<{twenga}prestashop>twenga_734b599bad38d4210614bc176c53fefe'] = 'Nombre del sitio';
$_MODULE['<{twenga}prestashop>twenga_dff4bf10409100d989495c6d5486035e'] = 'Apellido';
$_MODULE['<{twenga}prestashop>twenga_04176f095283bc729f1e3926967e7034'] = 'Nombre';
$_MODULE['<{twenga}prestashop>twenga_ce8ae9da5b7cd6c3df2929543a9af92d'] = 'Email';
$_MODULE['<{twenga}prestashop>twenga_bcc254b55c4a1babdf1dcb82c207506b'] = 'Teléfono';
$_MODULE['<{twenga}prestashop>twenga_28bea34e08fa23a7d394c93bad717733'] = 'Nombre del organismo';
$_MODULE['<{twenga}prestashop>twenga_4ff5049a0938728934387c4d9cf38f94'] = 'Información jurídica';
$_MODULE['<{twenga}prestashop>twenga_dfd7564600980a3470f2ec24766653fe'] = 'Información jurídica de la empresa.';
$_MODULE['<{twenga}prestashop>twenga_dd7bf230fde8d4836917806aff6a6b27'] = 'Dirección';
$_MODULE['<{twenga}prestashop>twenga_572ed696f21038e6cc6c86bb272a3222'] = 'Código postal';
$_MODULE['<{twenga}prestashop>twenga_57d056ed0984166336b7879c2af3657f'] = 'Ciudad';
$_MODULE['<{twenga}prestashop>twenga_c9cc8cce247e49bae79f15173ce97354'] = 'Guardar';
$_MODULE['<{twenga}prestashop>twenga_fcb0c2a30548efc7048ea4bdfa4eba05'] = 'Anular el tracking';
$_MODULE['<{twenga}prestashop>twenga_08473b95892d1cb8265ff2716cb81d54'] = 'Para anular el tracking, pulse en el siguiente link:';
$_MODULE['<{twenga}prestashop>twenga_bcfaccebf745acfd5e75351095a5394a'] = 'Anular';
$_MODULE['<{twenga}prestashop>twenga_2938a03ab100963b7349d83257fa9333'] = 'Activar el tracking';
$_MODULE['<{twenga}prestashop>twenga_cd07439a0c70b97a595de73218094a36'] = 'Para activar el tracking, pulse en el siguiente link:';
$_MODULE['<{twenga}prestashop>twenga_a13367a8e2a3f3bf4f3409079e3fdf87'] = 'Activar';
$_MODULE['<{twenga}prestashop>twengaobj_2823b98d043387f608f16d5830d63f5f'] = 'Para activar el módulo Twenga, la constante \"PARTNER_AUTH_KEY\" debe estar definida. La instalación por defecto de PrestaShop contiene este valor.';
$_MODULE['<{twenga}prestashop>twengaobj_9f7cd403f4ab77ce8c00426d4a01345e'] = 'El objeto para validar los campos debe ser una instancia de la clase TwengaFields';
$_MODULE['<{twenga}prestashop>twengaobj_b78d4ca3fa82bab9e21c8110511ed947'] = 'La devolución XML de la respuesta HTTP no puede ser analizada:';
$_MODULE['<{twenga}prestashop>twengaobj_7edc522b57a063ef075b68fdb791af40'] = 'la respuesta HTTP está vacía';
$_MODULE['<{twenga}prestashop>twengaobj_d00d3f61833c8686be3f0ca7df670e20'] = 'La llamada a los servicios Web Twenga no se ha obtenido con éxito y a devuelto un estado HTTP de %d. Lo que significa:';
$_MODULE['<{twenga}prestashop>twengaobj_5177c3a8e526ccb227441827d43d9583'] = 'La función que ha llamado no existe';
$_MODULE['<{twenga}prestashop>twengaobj_3718cdfdc7439f35aed9f053b5991baf'] = 'Un campo requerido está vacío.';
$_MODULE['<{twenga}prestashop>twengaobj_f97fd38d65fe891d07fc1a157b0752a2'] = 'El tipo de parámetro que ha enviado es diferente del que se esperaba.';
$_MODULE['<{twenga}prestashop>twengaobj_737b702af5cbf3c4b0e7404592bae85e'] = 'El hash key no es válido';
$_MODULE['<{twenga}prestashop>twengaobj_c54550e963195bd4e80b862f40b8d574'] = 'Se requiere el hash key';
$_MODULE['<{twenga}prestashop>twengaobj_c4e170c475b0285f284ccb066bcd81f4'] = 'No se han encontrado pedidos. Compruebe los parámetros que transmite';
$_MODULE['<{twenga}prestashop>twengaobj_54441256ce04ab07a29463646d0a9931'] = 'Se requiere una autentificación.';
$_MODULE['<{twenga}prestashop>twengaobj_802b207b05fe5cea22e11b9db804b33d'] = 'La autentificación ha fracasado.';
$_MODULE['<{twenga}prestashop>twengaobj_629a8cfa226f98886062bfdc9666e266'] = 'La URL no es válida.';
$_MODULE['<{twenga}prestashop>twengaobj_9fb66ea632c1aff220b180918df3c77c'] = 'El servidor ha encontrado un \"internal server error\".';
$_MODULE['<{twenga}prestashop>twengaobj_6e182f2ba494a6720ce552ed2a255403'] = 'El servidor no está accesible por el momento';
$_MODULE['<{twenga}prestashop>twengaobj_4252fb7eb531ed1ec250e5c16f8ced37'] = 'La llamada a los servicios Web Twenga a devuelto un estado HTTP inesperado:';
$_MODULE['<{twenga}prestashop>twengaobj_5619f08f21127bd8f72ec9bbb25031ac'] = 'Error  n°';
